{% if theme_versions %}
<div class="dropdown">
  <button class="btn btn-secondary dropdown-toggle version-select" type="button" tabindex="0" id="dropdownMenuButton" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
    Skuid Version: v{{ theme_version }} <span class="caret"></span></button>

  </button>
  <div class="dropdown-menu" aria-labelledby="dropdownMenuButton">
    {% for version in theme_versions %}
      <a class="dropdown-item" href="#" onclick="versionPick(this)">{{ version }}</a>
    {% endfor %}
  </div>
</div>
{% endif %}